==> deposits_oneclick_checkout-0.0.2.tar.gz: lib/app/model/tokenize_card/tokenise_card.dart <==
// To parse this JSON data, do
//
//     final tokenizeCardResponse = tokenizeCardResponseFromJson(jsonString);

import 'dart:convert';

TokenizeCardResponse tokenizeCardResponseFromJson(String str) => TokenizeCardResponse.fromJson(json.decode(str));

String tokenizeCardResponseToJson(TokenizeCardResponse data) => json.encode(data.toJson());

class TokenizeCardResponse {
    TokenizeCardResponse({
        this.status,
        this.message,
        this.data,
    });

    String? status;
    String? message;
    Data? data;

    factory TokenizeCardResponse.fromJson(Map<String, dynamic> json) => TokenizeCardResponse(
        status: json["status"],
        message: json["message"],
        data: json["data"] == null||json["data"] == '' || json["data"] ==  "" ? null : Data.fromJson(json["data"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data == null ? null : data!.toJson(),
    };
}

class Data {
    Data({
        this.id,
        this.authCode,
        this.primaryCard,
        this.status,
        this.cardOwnerName,
        this.cardOwnerEmail,
        this.cardOwnerPhone,
        this.metaDataJson,
        this.createdAt,
    });

    int? id;
    String? authCode;
    dynamic primaryCard;
    String? status;
    String? cardOwnerName;
    String? cardOwnerEmail;
    String? cardOwnerPhone;
    MetaDataJson? metaDataJson;
    String? createdAt;

    factory Data.fromJson(Map<String, dynamic> json) => Data(
        id: json["id"],
        authCode: json["auth_code"],
        primaryCard: json["primary_card"],
        status: json["status"],
        cardOwnerName: json["card_owner_name"],
        cardOwnerEmail: json["card_owner_email"],
        cardOwnerPhone: json["card_owner_phone"],
        metaDataJson: MetaDataJson.fromJson(json["meta_data_json"]),
        createdAt: json["created_at"],
    );

    Map<String, dynamic> toJson() => {
        "id": id,
        "auth_code": authCode,
        "primary_card": primaryCard,
        "status": status,
        "card_owner_name": cardOwnerName,
        "card_owner_email": cardOwnerEmail,
        "card_owner_phone": cardOwnerPhone,
        "meta_data_json": metaDataJson!.toJson(),
        "created_at": createdAt,
    };
}

class MetaDataJson {
    MetaDataJson({
        this.status,
        this.responseCode,
        this.responseMessage,
        this.token,
        this.expirationDate,
        this.cardType,
        this.maskedCardNumber,
        this.cardTransactionIdentifier,
        this.taskId,
        this.transactionId,
        this.transactionTimestamp,
        this.expiration,
        this.cvv,
        this.fullName,
        this.issuer,
    });

    String? status;
    String? responseCode;
    String? responseMessage;
    String? token;
    String? expirationDate;
    String? cardType;
    String? maskedCardNumber;
    String? cardTransactionIdentifier;
    String? taskId;
    String? transactionId;
    String? transactionTimestamp;
    String? expiration;
    String? cvv;
    String? fullName;
    List<Issuer>? issuer;

    factory MetaDataJson.fromJson(Map<String, dynamic> json) => MetaDataJson(
        status: json["status"],
        responseCode: json["responseCode"],
        responseMessage: json["responseMessage"],
        token: json["token"],
        expirationDate: json["expirationDate"],
        cardType: json["cardType"],
        maskedCardNumber: json["maskedCardNumber"],
        cardTransactionIdentifier: json["cardTransactionIdentifier"],
        taskId: json["taskID"],
        transactionId: json["transactionID"],
        transactionTimestamp: json["transactionTimestamp"],
        expiration: json["expiration"],
        cvv: json["cvv"],
        fullName: json["full_name"],
        issuer: List<Issuer>.from(json["issuer"].map((x) => Issuer.fromJson(x))),
    );

    Map<String, dynamic> toJson() => {
        "status": status,
        "responseCode": responseCode,
        "responseMessage": responseMessage,
        "token": token,
        "expirationDate": expirationDate,
        "cardType": cardType,
        "maskedCardNumber": maskedCardNumber,
        "cardTransactionIdentifier": cardTransactionIdentifier,
        "taskID": taskId,
        "transactionID": transactionId,
        "transactionTimestamp": transactionTimestamp,
        "expiration": expiration,
        "cvv": cvv,
        "full_name": fullName,
        "issuer": List<dynamic>.from(issuer!.map((x) => x.toJson())),
    };
}

class Issuer {
    Issuer({
        this.cardNumber,
        this.brand,
        this.cardType,
        this.bankName,
        this.country,
    });

    String? cardNumber;
    String? brand;
    String? cardType;
    String? bankName;
    String? country;

    factory Issuer.fromJson(Map<String, dynamic> json) => Issuer(
        cardNumber: json["Card_Number"],
        brand: json["Brand"],
        cardType: json["Card_Type"],
        bankName: json["Bank_Name"],
        country: json["Country"],
    );

    Map<String, dynamic> toJson() => {
        "Card_Number": cardNumber,
        "Brand": brand,
        "Card_Type": cardType,
        "Bank_Name": bankName,
        "Country": country,
    };
}

==> deposits_oneclick_checkout-0.0.3.tar.gz: lib/app/model/tokenize_card/tokenise_card.dart <==
// To parse this JSON data, do
//
//     final tokenizeCardResponse = tokenizeCardResponseFromJson(jsonString);

import 'package:deposits_oneclick_checkout/app/common/utils/exports.dart';

TokenizeCardResponse tokenizeCardResponseFromJson(String str) => TokenizeCardResponse.fromJson(json.decode(str));

String tokenizeCardResponseToJson(TokenizeCardResponse data) => json.encode(data.toJson());

class TokenizeCardResponse {
    TokenizeCardResponse({
        this.status,
        this.message,
        this.data,
    });

    String? status;
    String? message;
    TokenizeCardData? data;

    factory TokenizeCardResponse.fromJson(Map<String, dynamic> json) => TokenizeCardResponse(
        status: json["status"],
        message: json["message"],
        data: json["data"] == null||json["data"] == '' || json["data"] ==  "" ? null : TokenizeCardData.fromJson(json["data"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data == null ? null : data!.toJson(),
    };
}

class TokenizeCardData {
    TokenizeCardData({
        this.id,
        this.authCode,
        this.primaryCard,
        this.status,
        this.cardOwnerName,
        this.cardOwnerEmail,
        this.cardOwnerPhone,
        this.metaDataJson,
        this.createdAt,
    });

    int? id;
    String? authCode;
    dynamic primaryCard;
    String? status;
    String? cardOwnerName;
    String? cardOwnerEmail;
    String? cardOwnerPhone;
    MetaDataJson? metaDataJson;
    String? createdAt;

    factory TokenizeCardData.fromJson(Map<String, dynamic> json) => TokenizeCardData(
        id: json["id"],
        authCode: json["auth_code"],
        primaryCard: json["primary_card"],
        status: json["status"],
        cardOwnerName: json["card_owner_name"],
        cardOwnerEmail: json["card_owner_email"],
        cardOwnerPhone: json["card_owner_phone"],
        metaDataJson: MetaDataJson.fromJson(json["meta_data_json"]),
        createdAt: json["created_at"],
    );

    Map<String, dynamic> toJson() => {
        "id": id,
        "auth_code": authCode,
        "primary_card": primaryCard,
        "status": status,
        "card_owner_name": cardOwnerName,
        "card_owner_email": cardOwnerEmail,
        "card_owner_phone": cardOwnerPhone,
        "meta_data_json": metaDataJson!.toJson(),
        "created_at": createdAt,
    };
}
